[![pypi-version]][pypi]
[![build-status-image]][travis]
[![Coverage Status](https://coveralls.io/repos/github/danpoland/pyramid-restful-framework/badge.svg?branch=master)](https://coveralls.io/github/danpoland/pyramid-restful-framework?branch=master)

# pyramid-restful-framework
A RESTful API framework for Pyramid.


[build-status-image]: https://travis-ci.org/danpoland/pyramid-restful-framework.svg?branch=master
[travis]: https://travis-ci.org/danpoland/pyramid-restful-framework
[pypi-version]: https://badge.fury.io/py/pyramid-restful-framework.svg
[pypi]: https://pypi.python.org/pypi/pyramid-restful-framework
